@@ -37,6 +37,6 @@ def set_language_from_url(request, user_language):
 
     _url = parsed.path
     if len(_url) > 1:
-        _url = '/{}/'.format(user_language) + _url.lstrip('\/{}\/'.format(prev_lang))
+        _url = '/{}/'.format(user_language) + _url.lstrip('/{}/'.format(prev_lang))
 
     return redirect(_url)
