@@ -46,7 +46,7 @@ LOCALE_PATHS = [str(ROOT_DIR.path("locale"))]
 
 
 # pai
-TESTING_MODE = 'test' in sys.argv
+TESTING_MODE = 'test' in sys.argv or 'setup.py' in sys.argv
 
 # file uploads
 FILE_UPLOAD_PERMISSIONS = 0o644
@@ -90,17 +90,17 @@ META_USE_TITLE_TAG = False
 # DATABASES
 # ------------------------------------------------------------------------------
 # https://docs.djangoproject.com/en/dev/ref/settings/#databases
-if DEBUG:  # pai
+USE_SQLITE = env.bool("USE_SQLITE", default=TESTING_MODE)  # TESTING_MODE uses sqlite
+if USE_SQLITE:  # pai
     DATABASES = {
         'default': {
             'ENGINE': 'django.db.backends.sqlite3',
-            'NAME': os.path.join(ROOT_DIR, 'db.sqlite3'),
+            'NAME': os.path.join(ROOT_DIR, 'db.sqlite3')
         }
     }
     DATABASES["default"]["ATOMIC_REQUESTS"] = True
 else:
     DATABASES = {"default": env.db("DATABASE_URL")}
-DATABASES["default"]["ATOMIC_REQUESTS"] = True
 
 # URLS
 # ------------------------------------------------------------------------------
@@ -337,7 +337,7 @@ ACCOUNT_DEFAULT_HTTP_PROTOCOL = env("ACCOUNT_DEFAULT_HTTP_PROTOCOL", default="ht
 if DEBUG:
     CSRF_COOKIE_DOMAIN = None
     CSRF_TRUSTED_ORIGINS = ['*']
-#else:
+#else:  # defaults to APP_DOMAIN
 #    CSRF_COOKIE_DOMAIN = COOKIE_DOMAIN
 #    CSRF_TRUSTED_ORIGINS = ['.{0}'.format(COOKIE_DOMAIN)]
 
@@ -395,7 +395,11 @@ LOGGING = {
             "formatter": "verbose",
         }
     },
-    "root": {"level": "DEBUG", "handlers": ["console"]},
+    "loggers": {
+        "root": {"level": "DEBUG", "handlers": ["console"]},
+        "environ": {"level": "INFO", "handlers": ["console"]},
+        "factory": {"level": "INFO", "handlers": ["console"]},
+    }
 }
 
 # Celery
