@@ -5,11 +5,8 @@ from urllib.parse import urlencode, urljoin
 # pyximport.install()
 
 from django.http import Http404
-from django.shortcuts import redirect, reverse
-# from django.views.decorators.csrf import csrf_exempt
-
-# from rest_framework.response import Response
-# from rest_framework import status
+from django.shortcuts import redirect
+from django.urls import reverse
 
 from allauth.account.adapter import get_adapter
 
@@ -141,8 +138,6 @@ def passepartout_login_view(request, token):
                 else:
                     set_cookie(response, app_settings.JWT_COOKIE_NAME, jwt_token)
 
-                set_session_key(request, '__dssoa__requesting_user', user)
-
             else:
                 logger.warning('user "{}" can not authenticate'.format(user))
 
