@@ -210,7 +210,6 @@ class UserSerializer(AbsoluteUrlSerializer):
             logger.info('User "{}" is changing email for user "{}"'.format(requesting_user,
                                                                            user))
 
-
             adapter.validate_unique_email(new_email)
 
             created_email = EmailAddress.objects.add_email(request, user,
@@ -284,7 +283,6 @@ class NewUserSerializer(UserSerializer):
     def create(self, validated_data):
         request = self.context.get('request')
         requesting_user = request.user
-        adapter = get_adapter(request)
 
         requesting_user_is_staff = is_staff(requesting_user)
         skip_confirmation = request.GET.get('skip_confirmation', None)
@@ -329,7 +327,7 @@ class NewUserSerializer(UserSerializer):
                     for new_subscription in profile_object_subscriptions:
                         new_subscription_service_name = new_subscription.get('service').get('name')
                         service = Service.objects.get(name=new_subscription_service_name)
-                        adapter.subscribe_profile_to_service(new_user.sso_app_profile, service)
+                        service.subscribe(new_user.get_sso_app_profile())
 
             except Exception:
                 logger.exception('Error subscribing service on user creation')
