@@ -41,7 +41,11 @@ class DjangoSsoAppAuthenticationAppMiddleware(DjangoSsoAppAuthenticationBaseMidd
             if app_settings.REPLICATE_PROFILE:
                 check_user_can_login(user)
             else:
-                check_user_can_login(user, skip_profile_completion_checks=True)
+                if app_settings.SERVICE_SUBSCRIPTION_REQUIRED:
+                    check_user_can_login(user, skip_profile_completion_checks=True)
+                else:
+                    check_user_can_login(user, skip_profile_completion_checks=True,
+                                         skip_service_subscription_checks=True)
 
             if app_settings.MANAGE_USER_GROUPS:
                 # default groups check
