@@ -11,7 +11,7 @@ from .apps.emails.models import EmailAddress
 from .apps.services.models import Service
 from .apps.groups.models import Group
 
-from .utils import set_session_key
+from .utils import get_random_fingerprint
 from . import app_settings
 
 logger = logging.getLogger('django_sso_app.core')
@@ -25,8 +25,13 @@ SIGNUP_FORM_FIELDS = app_settings.USER_FIELDS + (
 
 
 class LoginForm(allauth_LoginForm):
-    fingerprint = CharField(label='fingerprint', max_length=255, required=False, widget=HiddenInput(),
-                            initial='undefined')
+    fingerprint = CharField(label='fingerprint', max_length=255, required=False, widget=HiddenInput())
+
+    def __init__(self, *args, **kwargs):
+        super(LoginForm, self).__init__(*args, **kwargs)
+
+        request = kwargs.get('request', None)
+        self.fields['fingerprint'].initial = get_random_fingerprint(request)
 
     def login(self, request, redirect_url=None):
         res = super(LoginForm, self).login(request, redirect_url)
@@ -48,8 +53,7 @@ class LoginForm(allauth_LoginForm):
 
 
 class BaseSignupForm(allauth_SignupForm):
-    fingerprint = CharField(label='fingerprint', max_length=255, required=False, widget=HiddenInput(),
-                            initial='undefined')
+    fingerprint = CharField(label='fingerprint', max_length=255, required=False, widget=HiddenInput())
 
     referer = CharField(label='referer', max_length=255, required=False, widget=HiddenInput(),
                         initial=app_settings.APP_URL)
@@ -66,6 +70,9 @@ class BaseSignupForm(allauth_SignupForm):
         if 'email' not in app_settings.USER_FIELDS:
             self.fields.pop('email')
 
+        request = kwargs.get('request', None)
+        self.fields['fingerprint'].initial = get_random_fingerprint(request)
+
     def get_form_kwargs(self):
         """Return the keyword arguments for instantiating the form."""
         kwargs = super(BaseSignupForm, self)
