@@ -1,16 +1,23 @@
 import os
+import logging
 import datetime
 import binascii
 from random import seed, randint
 import base64
 
 from django.core.management.utils import get_random_secret_key
+from django.utils.http import urlencode
+from django.http import HttpResponseRedirect
 from django.conf import settings
 
-from .exceptions import ProfileIncompleteException, DectivatedUserException, UnsubscribedUserException, DjangoStaffUsersCanNotLoginException
+from .tokens.utils import logger
+from .exceptions import (ProfileIncompleteException, DectivatedUserException, UnsubscribedUserException,
+                         DjangoStaffUsersCanNotLoginException, ServiceSubscriptionRequiredException,
+                         AnonymousUserException)
 from .permissions import is_authenticated, is_django_staff
 from . import app_settings
 
+logger = logging.getLogger('django_sso_app.core')
 # initializing seed
 SEED = int(base64.b16encode(bytes(get_random_secret_key(), 'utf-8')), 16)
 seed(SEED)
@@ -89,13 +96,49 @@ def get_session_key(request, key, default=None):
     return getattr(request, key, default)
 
 
-def check_user_can_login(user, skip_profile_checks=False):
+def redirect_to_profile_complete(user):
+    if app_settings.BACKEND_ENABLED:
+        url = app_settings.PROFILE_COMPLETE_URL
+    else:
+        _qs = urlencode({'next': app_settings.SERVICE_URL})
+        url = '{}{}?{}'.format(app_settings.BACKEND_URL, app_settings.PROFILE_COMPLETE_URL, _qs)
+
+    logger.info('User {} must complete profile,'
+                ' redirecting to {} ...'
+                .format(user, url))
+
+    response = HttpResponseRedirect(redirect_to=url)
+
+    raise ProfileIncompleteException(response)
+
+
+def redirect_to_service_subscription(user, service_url=None):
+    if app_settings.BACKEND_ENABLED:
+        url = app_settings.LOGIN_URL
+    else:
+        if service_url is None:
+            service_url = app_settings.SERVICE_URL
+
+        _qs = urlencode({'next': service_url})
+        url = '{}{}?{}'.format(app_settings.BACKEND_URL, app_settings.LOGIN_URL, _qs)
+
+    logger.info('User {} must agree to the Terms of Service,'
+                ' redirecting to {} ...'
+                .format(user, url))
+
+    response = HttpResponseRedirect(redirect_to=url)
+
+    raise ServiceSubscriptionRequiredException(response)
+
+
+def check_user_can_login(user, skip_profile_completion_checks=False, skip_service_subscription_checks=False):
     """
     Check user login ability
     :param user:
+    :param skip_profile_completion_checks:
+    :param skip_service_subscription_checks:
     :return:
     """
-
     if is_authenticated(user):
         if is_django_staff(user):
             raise DjangoStaffUsersCanNotLoginException()
@@ -105,15 +148,21 @@ def check_user_can_login(user, skip_profile_checks=False):
             if user.sso_app_profile.is_unsubscribed:
                 raise UnsubscribedUserException()
             else:
-                if not skip_profile_checks:
+                if not skip_profile_completion_checks:
                     if user.sso_app_profile.is_incomplete:
-                        raise ProfileIncompleteException(app_settings.PROFILE_COMPLETE_URL)
+                        redirect_to_profile_complete(user)
+
+                if not skip_service_subscription_checks:
+                    if user.sso_app_profile.must_subscribe:
+                        redirect_to_service_subscription(user)
+    else:
+        raise AnonymousUserException()
 
 
 def get_random_token(length=4):
     """
     Returns random token
-    :param request:
+    :param length:
     :return:
     """
     start = randint(0, 4095 - length)
